<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversa</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Apenas na primeira vez</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Atender conferências</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Status Invisível</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Status ocupado</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Status disponível</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Resposta automática</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Texto da resposta automática</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Escolher Status</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>Eu estou ocupado.</translation>
    </message>
</context>
<context>
    <name>AutoresponderMessageFilter</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>